/**

RestrictedNumber variables:
-------------------------------------------------------------------
value:				The value of the RestrictedNumber data type
max: 				The maximum number that can be stored in value
min: 				The minimum number that can be stored in value

RestrictedNumber initialization:
-------------------------------------------------------------------
New(_min,_max,_value)
Param:_min			the minimum value of the new RestrictedNumber
Param:_max			the maximum value of the new RestrictedNumber
Param:_value		the value of the new RestrictedNumber
Initializes the new RestrictedNumber based on specified min, max,
and value arguments. Also accounts for minimum and maximum bounds
when assigning the initial value.

RestrictedNumber procedures:
-------------------------------------------------------------------
GetValue()
Returns the value of the RestrictedNumber

SetValue(_value)
Param:_value		The new value of the RestrictedNumber
Sets the new value of the restricted number. Defaults to max or min
if the new value is out of bounds.

SetMax(_max)
Param:_max			The new maximum value of the RestrictedNumber
Sets the new maximum value of the restricted number. Also adjusts
the RestrictedNumber's value to keep it in bounds if necessary.

SetMin(_min)
Param:_min			The new minimum value of the RestrictedNumber
Sets the new minimum value of the restricted number. Also adjusts
the RestrictedNumber's value to keep it in bounds if necessary.

Subtract(amount)
Param:amount		The amount to decrease the RestrictedNumber's value by
Decreases the RestrictedNumber's value by a specified amount while keeping
the max and min values in mind.

Add(amount)
param:amount		The amount to increase the RestrictedNumber's value by
Increases the RestrictedNumber's value by a specified amount while keeping
the max and min values in mind.

atMax()
Returns true if the RestrictedNumber's value is equal to its max

atMin()
Returns true if the RestrictedNumber's value is equal to its min
*/

RestrictedNumber
{
	var
	{
		value
		max
		min
	}

	proc/GetValue()
	{
		return value
	}

	proc/SetValue(_value = 0)
	{
		if(_value < min) value = min
		else if(_value > max) value = max
		else value = _value
	}

	proc/SetMax(_max)
	{
		max = _max
		SetValue(value)
	}

	proc/SetMin(_min)
	{
		min = _min
		SetValue(value)
	}

	proc/Subtract(amount)
	{
		SetValue(value - amount)
	}

	proc/Add(amount)
	{
		SetValue(value + amount)
	}

	proc/atMax()
	{
		return value == max
	}

	proc/atMin()
	{
		return value == min
	}

	New(_min = 0,_max = 0,_value = 0)
	{
		min = _min
		max = _max
		value = SetValue(_value)
	}
}